summaryrefslogtreecommitdiff
path: root/linux
diff options
context:
space:
mode:
Diffstat (limited to 'linux')
-rw-r--r--linux/drivers/media/dvb/dvb-core/dvb_frontend.c2
1 files changed, 1 insertions, 1 deletions
diff --git a/linux/drivers/media/dvb/dvb-core/dvb_frontend.c b/linux/drivers/media/dvb/dvb-core/dvb_frontend.c
index 864c3b5b8..3b8225f9e 100644
--- a/linux/drivers/media/dvb/dvb-core/dvb_frontend.c
+++ b/linux/drivers/media/dvb/dvb-core/dvb_frontend.c
@@ -559,7 +559,7 @@ static int dvb_frontend_thread (void *data)
// fast zigzag
if (fe->state & FESTATE_SEARCHING_FAST) {
- delay = (HZ * 30) / 1000; // hardcoded fast zigzag scan delay of 30ms
+ delay = (HZ * 50) / 1000; // hardcoded fast zigzag scan delay of 50ms
// OK, if we've run out of trials at the fast speed. Drop back to
// slow for the _next_ attempt